@@ -24,8 +24,6 @@
 #include "gom-resource-priv.h"
 #include "gom-sorting.h"
 
-G_DEFINE_TYPE(GomCommandBuilder, gom_command_builder, G_TYPE_OBJECT)
-
 struct _GomCommandBuilderPrivate
 {
    GomAdapter *adapter;
@@ -38,6 +36,8 @@ struct _GomCommandBuilderPrivate
    GType m2m_type;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(GomCommandBuilder, gom_command_builder, G_TYPE_OBJECT)
+
 enum
 {
    PROP_0,
@@ -459,6 +459,8 @@ gom_command_builder_build_create (GomCommandBuilder *builder,
 
    /* Create the table if it doesn't already exist */
    if (table_is_new_in_version(klass, version)) {
+      g_debug ("Creating table '%s' new in version %d (if it does not exist)", klass->table, version);
+
       str = g_string_new("CREATE TABLE IF NOT EXISTS ");
       add_table_name(str, klass);
       g_string_append(str, "(");
@@ -493,6 +495,9 @@ gom_command_builder_build_create (GomCommandBuilder *builder,
      if (pspecs[i] != primary_pspec &&
          is_mapped(pspecs[i]) &&
          is_new_in_version(pspecs[i], version)) {
+       g_debug ("Adding column '%s' to table '%s' new in version %d",
+                pspecs[i]->name, klass->table, version);
+
        str = g_string_new("ALTER TABLE ");
        add_table_name(str, klass);
        g_string_append(str, " ADD COLUMN ");
@@ -1027,7 +1032,6 @@ gom_command_builder_class_init (GomCommandBuilderClass *klass)
    object_class->finalize = gom_command_builder_finalize;
    object_class->get_property = gom_command_builder_get_property;
    object_class->set_property = gom_command_builder_set_property;
-   g_type_class_add_private(object_class, sizeof(GomCommandBuilderPrivate));
 
    gParamSpecs[PROP_ADAPTER] =
       g_param_spec_object("adapter",
@@ -1115,8 +1119,5 @@ gom_command_builder_class_init (GomCommandBuilderClass *klass)
 static void
 gom_command_builder_init (GomCommandBuilder *builder)
 {
-   builder->priv =
-      G_TYPE_INSTANCE_GET_PRIVATE(builder,
-                                  GOM_TYPE_COMMAND_BUILDER,
-                                  GomCommandBuilderPrivate);
+   builder->priv = gom_command_builder_get_instance_private(builder);
 }
